﻿-- ---------------------------------------------------------------------------
-- Description:
-- Create SAR database objects under the AMLCTR schema.
--
-- Usage:
-- This script is a template for creating the tablespaces, tables,
-- indexes, and constraints required for the FINTRAC SAR AML schema.
--      It should be run only by those sites implementing this unsupported
--      customization.  The standard mysql_base_sar_ddl.sql script must
--      be run PRIOR TO the execution of this script.
--
-- ---------------------------------------------------------------------------

SET FOREIGN_KEY_CHECKS = 0;

USE `AMLCTR`;

CREATE TABLE AMLCTR.FIN_CONTACT_CONTROL
(
	REPORT_TYPE           CHAR(4) NOT NULL,
	RPT_ENT_CNTCT_SURNAME  VARCHAR(20) NULL,
	RPT_ENT_CNTCT_GIVEN_NAME  VARCHAR(15) NULL,
	RPT_ENT_CNTCT_OTH_NAME  VARCHAR(10) NULL,
	RPT_ENT_CNTCT_PH      VARCHAR(20) NULL,
	RPT_ENT_CNTCT_PH_EXT  NUMERIC(10,0) NULL,
	 PRIMARY KEY (REPORT_TYPE)
)
;



CREATE UNIQUE INDEX XPKCONTACT ON FIN_CONTACT_CONTROL
(
	REPORT_TYPE
)
;



CREATE TABLE AMLCTR.FIN_ENTITY_CONTROL
(
	ENTITY_ID             VARCHAR(20) NULL,
	ENTITY_NAME           VARCHAR(50) NULL,
	ENTITY_TYPE           CHAR(1) NULL,
	LAST_MODIFIED         NUMERIC(8,0) NULL,
	PKI_NUMBER            VARCHAR(20) NULL
)
;



CREATE TABLE AMLCTR.FINTRAC_COUNTRY_LOOKUP
(
	FINTRAC_COUNTRY       CHAR(2) NULL,
	WIRES_COUNTRY         CHAR(2) NULL
)
;



CREATE TABLE AMLCTR.FINTRAC_TRANSACTION_TYPE_LOOKUP
(
	TRANSACTION_TYPE_KEY  INTEGER NOT NULL,
	DISP_TYPE             CHAR(1) NULL,
	TRAN_METHOD           CHAR(1) NULL,
	DISP_TYPE_OTHER       VARCHAR(50) NULL,
	TRAN_METHOD_OTHER     VARCHAR(50) NULL,
	DISPOSITION_OF_FUNDS  CHAR(1) NULL,
	DISPOSITION_OTHER     VARCHAR(50) NULL,
	 PRIMARY KEY (TRANSACTION_TYPE_KEY)
)
;



CREATE UNIQUE INDEX XPKFINTRAC_TRANSACTION_TYPE_LOOKUP ON FINTRAC_TRANSACTION_TYPE_LOOKUP
(
	TRANSACTION_TYPE_KEY
)
;



CREATE TABLE AMLCTR.IDENTITY_DOCUMENT
(
	ID_CODE               CHAR(3) NULL,
	ID_DESC               VARCHAR(30) NULL,
	FINTRAC_ID            CHAR(1) NULL
)
;



CREATE TABLE AMLCTR.LSTR_ACTION
(
	PART_SEQ_NUM          NUMERIC(2,0) NOT NULL,
	SAR_ID                NUMERIC(15,0) NOT NULL,
	PART_ID               CHAR(2) NULL,
	ACT_ACTION_DESC       VARCHAR(400) NULL,
	 PRIMARY KEY (PART_SEQ_NUM,SAR_ID)
)
;



CREATE UNIQUE INDEX XPKLSTR_ACTION ON LSTR_ACTION
(
	PART_SEQ_NUM,
	SAR_ID
)
;



CREATE TABLE AMLCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE
(
	LOGICAL_SAR_ID        NUMERIC(15,0) NOT NULL,
	PHYSICAL_SAR_ID       NUMERIC(15,0) NOT NULL,
	 PRIMARY KEY (LOGICAL_SAR_ID,PHYSICAL_SAR_ID)
)
;



CREATE UNIQUE INDEX XPKLSTR_LOGICAL_PHYSICAL_BRIDGE ON LSTR_LOGICAL_PHYSICAL_BRIDGE
(
	LOGICAL_SAR_ID,
	PHYSICAL_SAR_ID
)
;



CREATE TABLE AMLCTR.LSTR_NARATIVE
(
	SUSP_PART_SEQ_NUM     NUMERIC(2,0) NOT NULL,
	SAR_ID                NUMERIC(15,0) NOT NULL,
	SUSP_PART_ID          CHAR(2) NULL,
	SUSP_ACTIVITY_DESC    VARCHAR(400) NULL,
	 PRIMARY KEY (SUSP_PART_SEQ_NUM,SAR_ID)
)
;



CREATE UNIQUE INDEX XPKLSTR_ACTION ON LSTR_NARATIVE
(
	SUSP_PART_SEQ_NUM,
	SAR_ID
)
;



CREATE TABLE AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS
(
	SAR_ID                NUMERIC(15,0) NOT NULL,
	ALERT_ID              NUMERIC(15,0) NOT NULL,
	branch_key            NUMERIC(10) NOT NULL,
	date_key              NUMERIC(8,0) NOT NULL,
	time_key              NUMERIC(6) NOT NULL,
	account_key           NUMERIC(10) NOT NULL,
	transaction_key       NUMERIC(10) NOT NULL,
	transaction_currency_key  NUMERIC(5) NOT NULL,
	transaction_type_key  NUMERIC(10) NOT NULL,
	country_key           NUMERIC(5) NOT NULL,
	executing_party_key   NUMERIC(10) NOT NULL,
	associate_key         NUMERIC(10) NOT NULL,
	user_id               VARCHAR(35) NULL,
	ext_party_account_key  NUMERIC(10) NOT NULL,
	currency_amount       NUMERIC(15,5) NOT NULL,
	currency_amount_in_txn_ccy  NUMERIC(15,5) NOT NULL,
	currency_amount_in_account_ccy  NUMERIC(15,5) NOT NULL,
	posted_date_key       NUMERIC(8) NULL,
	debit_credit_indicator  CHAR(1) NULL,
	update_date           DATETIME NULL,
	 PRIMARY KEY (SAR_ID,ALERT_ID,branch_key,date_key,time_key,account_key,transaction_key,transaction_currency_key,transaction_type_key,country_key,executing_party_key,associate_key)
)
;



CREATE UNIQUE INDEX XPKLSTR_SUSPICIOUS_TRANSACTIONS ON LSTR_SUSPICIOUS_TRANSACTIONS
(
	SAR_ID,
	ALERT_ID,
	branch_key,
	date_key,
	time_key,
	account_key,
	transaction_key,
	transaction_currency_key,
	transaction_type_key,
	country_key,
	executing_party_key,
	associate_key
)
;



CREATE TABLE AMLCTR.SIC_LOOKUP
(
	CODE                  CHAR(4) NULL,
	SIC_DESCRIPTION       VARCHAR(50) NULL
)
;



CREATE TABLE AMLCTR.STR_ACCOUNT_HOLDER_CORP
(
	TRAN_SEQ_NUM          NUMERIC(2,0) NOT NULL,
	DISP_PART_SEQ_NUM     NUMERIC(2,0) NOT NULL,
	SAR_ID                NUMERIC(15,0) NOT NULL,
	BUSS_PART_SEQ_NUM     NUMERIC(2,0) NOT NULL,
	BUSS_PART_ID          CHAR(2) NOT NULL,
	BUSS_FULL_NAME        VARCHAR(35) NULL,
	BUSS_TYPE             VARCHAR(20) NULL,
	BUSS_ST_ADDRESS       VARCHAR(30) NULL,
	BUSS_CITY             VARCHAR(25) NULL,
	BUSS_PROV             VARCHAR(20) NULL,
	BUSS_COUNTRY          CHAR(2) NULL,
	BUSS_POCODE           CHAR(9) NULL,
	BUSS_PH               VARCHAR(20) NULL,
	BUSS_PH_EXT           NUMERIC(10,0) NULL,
	BUSS_INC              CHAR(14) NULL,
	BUSS_INC_PROV         VARCHAR(20) NULL,
	BUSS_INC_CNTRY        CHAR(2) NULL,
	BUSS_SIGN_AUTH_1      VARCHAR(35) NULL,
	BUSS_SIGN_AUTH_2      VARCHAR(35) NULL,
	BUSS_SIGN_AUTH_3      VARCHAR(35) NULL,
	 PRIMARY KEY (TRAN_SEQ_NUM,DISP_PART_SEQ_NUM,SAR_ID,BUSS_PART_SEQ_NUM)
)
;



CREATE UNIQUE INDEX XPKACCOUNT_HOLDER_CORP ON STR_ACCOUNT_HOLDER_CORP
(
	TRAN_SEQ_NUM,
	DISP_PART_SEQ_NUM,
	SAR_ID,
	BUSS_PART_SEQ_NUM
)
;



CREATE INDEX XIF1ACCOUNT_HOLDER_CORP ON STR_ACCOUNT_HOLDER_CORP
(
	DISP_PART_SEQ_NUM,
	TRAN_SEQ_NUM,
	SAR_ID
)
;



CREATE TABLE AMLCTR.STR_ACCOUNT_HOLDER_PERSONAL
(
	AH_PART_SEQ_NUM       NUMERIC(2,0) NOT NULL,
	TRAN_SEQ_NUM          NUMERIC(2,0) NOT NULL,
	DISP_PART_SEQ_NUM     NUMERIC(2,0) NOT NULL,
	SAR_ID                NUMERIC(15,0) NULL,
	AH_PART_ID            CHAR(2) NOT NULL,
	AH_SURNAME            VARCHAR(20) NULL,
	AH_GIVEN_NAME         VARCHAR(15) NULL,
	AH_INITIAL            CHAR(10) NULL,
	AH_OTH_SURNAME        VARCHAR(20) NULL,
	AH_OTH_GIVEN_NAME     VARCHAR(15) NULL,
	AH_OTH_INITIAL        VARCHAR(10) NULL,
	AH_ST_ADDRESS         VARCHAR(30) NULL,
	AH_CITY               VARCHAR(20) NULL,
	AH_PROV               VARCHAR(20) NULL,
	AH_COUNTRY            CHAR(2) NULL,
	AH_PCODE              CHAR(9) NULL,
	AH_HOME_PH            VARCHAR(20) NULL,
	AH_HOME_PH_EXT        NUMERIC(10,0) NULL,
	AH_OFF_PH             VARCHAR(20) NULL,
	AH_OFF_PH_EXT         NUMERIC(10,0) NULL,
	AH_DOB                CHAR(8) NULL,
	AH_IDENT              CHAR(1) NULL,
	AH_OTH_IDENT          VARCHAR(20) NULL,
	AH_ID_NUM             VARCHAR(20) NULL,
	AH_RES_COUNTRY        CHAR(2) NULL,
	AH_COUNTRY_CITIZEN    CHAR(2) NULL,
	AH_ID_ISSUE_PROV      VARCHAR(20) NULL,
	AH_ID_ISSUE_COUNTRY   CHAR(2) NULL,
	AH_OCC                VARCHAR(20) NULL,
	AH_EMPLYR             VARCHAR(35) NULL,
	AH_EMPLYR_ST_ADDRESS  VARCHAR(30) NULL,
	AH_EMPLYR_CITY        VARCHAR(20) NULL,
	AH_EMPLYR_PROV        VARCHAR(20) NULL,
	AH_EMPLYR_COUNTRY     CHAR(2) NULL,
	AH_EMPLYR_POCODE      CHAR(9) NULL,
	AH_EMPLYR_PH          CHAR(20) NULL,
	AH_EMPLYR_PH_EXT      NUMERIC(10,0) NULL,
	TP_REL_TO_AH          CHAR(1) NULL,
	TP_REL_TO_AH_OTH      VARCHAR(20) NULL,
	 PRIMARY KEY (AH_PART_SEQ_NUM,TRAN_SEQ_NUM,DISP_PART_SEQ_NUM)
)
;



CREATE UNIQUE INDEX XPKACCOUNT_HOLDER_PERSONAL ON STR_ACCOUNT_HOLDER_PERSONAL
(
	AH_PART_SEQ_NUM,
	TRAN_SEQ_NUM,
	DISP_PART_SEQ_NUM
)
;



CREATE INDEX XIF1ACCOUNT_HOLDER_PERSONAL ON STR_ACCOUNT_HOLDER_PERSONAL
(
	DISP_PART_SEQ_NUM,
	TRAN_SEQ_NUM,
	SAR_ID
)
;



CREATE TABLE AMLCTR.STR_ACCOUNT_INFO
(
	ACCT_PART_SEQ_NUM     NUMERIC(2,0) NOT NULL,
	SAR_ID                NUMERIC(15,0) NOT NULL,
	DISP_PART_SEQ_NUM     SMALLINT NOT NULL,
	TRAN_SEQ_NUM          SMALLINT NOT NULL,
	ACCT_PART_ID          CHAR(2) NOT NULL,
	ACCT_BRANCH_NUM       CHAR(12) NULL,
	ACCT_NUMBER           CHAR(30) NULL,
	ACCT_TYPE             CHAR(1) NULL,
	ACCT_OTH_TYPE         VARCHAR(20) NULL,
	ACCT_CURR             CHAR(3) NULL,
	ACCT_FULL_NAME1       VARCHAR(45) NULL,
	ACCT_FULL_NAME2       VARCHAR(45) NULL,
	ACCT_FULL_NAME3       VARCHAR(45) NULL,
	ACCT_OPEN_DATE        CHAR(8) NULL,
	ACCT_CLOSE_DATE       CHAR(8) NULL,
	ACCT_STATUS           CHAR(1) NULL,
	 PRIMARY KEY (ACCT_PART_SEQ_NUM,SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM)
)
;



CREATE UNIQUE INDEX XPKON_BEHALF ON STR_ACCOUNT_INFO
(
	ACCT_PART_SEQ_NUM,
	SAR_ID,
	DISP_PART_SEQ_NUM,
	TRAN_SEQ_NUM
)
;



CREATE INDEX XIF1ON_BEHALF ON STR_ACCOUNT_INFO
(
	DISP_PART_SEQ_NUM,
	TRAN_SEQ_NUM,
	SAR_ID
)
;



CREATE TABLE AMLCTR.STR_ACTION
(
	PART_SEQ_NUM          SMALLINT NOT NULL,
	SAR_ID                NUMERIC(15,0) NOT NULL,
	PART_ID               CHAR(2) NOT NULL,
	ACT_ACTION_DESC       VARCHAR(400) NULL,
	 PRIMARY KEY (PART_SEQ_NUM,SAR_ID)
)
;



CREATE UNIQUE INDEX XPKSTR_ACTION ON STR_ACTION
(
	PART_SEQ_NUM,
	SAR_ID
)
;



CREATE INDEX XIF1STR_ACTION ON STR_ACTION
(
	SAR_ID
)
;



CREATE TABLE AMLCTR.STR_BATCH_HEADER
(
	BATCH_SEQ_ID          NUMERIC(5,0) NOT NULL,
	BATCH_DATE            CHAR(8) NOT NULL,
	BATCH_TIME            NUMERIC(6,0) NOT NULL,
	RECORD_TYPE           CHAR(2) NULL,
	CODE_FORMAT           CHAR(4) NULL,
	REPORT_TYPE           CHAR(4) NULL,
	REPORT_ENTITY_ID      CHAR(10) NULL,
	CONTACT_SURNAME       VARCHAR(20) NULL,
	CONTACT_GIVEN_NAME    VARCHAR(15) NULL,
	CONTACT_PH_NUM        CHAR(20) NULL,
	CONTACT_PH_NUM_EXT    NUMERIC(5,0) NULL,
	BATCH_TYPE            CHAR(1) NULL,
	REASON_CODE           NUMERIC(1,0) NULL,
	SUB_HDR_COUNT         NUMERIC(5,0) NULL,
	REPORT_COUNT          NUMERIC(5,0) NULL,
	FORMAT_IND            SMALLINT NULL,
	OPER_MODE             CHAR(1) NULL,
	UPDATE_DATE           CHAR(8) NULL,
	UPDATE_ID             VARCHAR(35) NULL,
	 PRIMARY KEY (BATCH_SEQ_ID,BATCH_DATE,BATCH_TIME)
)
;



CREATE UNIQUE INDEX XPKSTR_BATCH ON STR_BATCH_HEADER
(
	BATCH_SEQ_ID,
	BATCH_DATE,
	BATCH_TIME
)
;



CREATE TABLE AMLCTR.STR_BATCH_RUN
(
	SAR_ID                NUMERIC(15,0) NOT NULL,
	BATCH_SEQ_NUM         NUMERIC(5,0) NOT NULL,
	RPT_SEQ_NUM           NUMERIC(5,0) NULL,
	BATCH_DATE            CHAR(8) NULL,
	BATCH_TIME            NUMERIC(8,0) NULL,
	ACCT_NUMBER           CHAR(30) NULL
)
;



CREATE TABLE AMLCTR.STR_BATCH_SUB_HEADER
(
	SEQ_NUM               NUMERIC(5,0) NOT NULL,
	BATCH_SEQ_ID          NUMERIC(5,0) NOT NULL,
	BATCH_DATE            CHAR(8) NOT NULL,
	BATCH_TIME            NUMERIC(6,0) NOT NULL,
	REPORT_ENTITY_ID      CHAR(25) NULL,
	REPORT_COUNT          NUMERIC(5,0) NULL,
	RECORD_TYPE           CHAR(2) NULL,
	 PRIMARY KEY (SEQ_NUM,BATCH_SEQ_ID,BATCH_DATE,BATCH_TIME)
)
;



CREATE UNIQUE INDEX XPKBATCH_SUB_HEADER ON STR_BATCH_SUB_HEADER
(
	SEQ_NUM,
	BATCH_SEQ_ID,
	BATCH_DATE,
	BATCH_TIME
)
;



CREATE INDEX XIF1BATCH_SUB_HEADER ON STR_BATCH_SUB_HEADER
(
	BATCH_SEQ_ID,
	BATCH_DATE,
	BATCH_TIME
)
;



CREATE TABLE AMLCTR.STR_DISPOSITION
(
	SAR_ID                NUMERIC(15,0) NOT NULL,
	DISP_PART_SEQ_NUM     SMALLINT NOT NULL,
	TRAN_SEQ_NUM          SMALLINT NOT NULL,
	DISP_PART_ID          CHAR(2) NOT NULL,
	DISP_TYPE             CHAR(1) NULL,
	DISP_LIP_NUM          VARCHAR(20) NULL,
	DISP_OTH_FUNDS        VARCHAR(20) NULL,
	DISP_AMOUNT           NUMERIC(15,2) NULL,
	DISP_CURRENCY         CHAR(3) NULL,
	DISP_OTH_ENT_NAME     VARCHAR(35) NULL,
	DISP_OTH_ACCT_NUM     CHAR(30) NULL,
	DISP_ON_BEHALF_IND    CHAR(1) NULL,
	 PRIMARY KEY (SAR_ID,DISP_PART_SEQ_NUM,TRAN_SEQ_NUM)
)
;



CREATE UNIQUE INDEX XPKSTR_DISPOSITION ON STR_DISPOSITION
(
	SAR_ID,
	DISP_PART_SEQ_NUM,
	TRAN_SEQ_NUM
)
;



CREATE INDEX XIF1STR_DISPOSITION ON STR_DISPOSITION
(
	TRAN_SEQ_NUM,
	SAR_ID
)
;



CREATE TABLE AMLCTR.STR_NARATIVE
(
	SUSP_PART_SEQ_NUM     SMALLINT NOT NULL,
	SAR_ID                NUMERIC(15,0) NOT NULL,
	SUSP_PART_ID          CHAR(2) NOT NULL,
	SUSP_ACTIVITY_DESC    VARCHAR(400) NULL,
	 PRIMARY KEY (SUSP_PART_SEQ_NUM,SAR_ID)
)
;



CREATE UNIQUE INDEX XPKSTR_NARATIVE ON STR_NARATIVE
(
	SUSP_PART_SEQ_NUM,
	SAR_ID
)
;



CREATE INDEX XIF1STR_NARATIVE ON STR_NARATIVE
(
	SAR_ID
)
;



CREATE TABLE AMLCTR.STR_REPORTING_ENTITY
(
	SAR_ID                NUMERIC(15,0) NOT NULL,
	PART_ID               CHAR(2) NOT NULL,
	RPT_ENT_ID            CHAR(12) NULL,
	RPT_ENT_FULL_NAME     CHAR(35) NULL,
	RPT_ENT_ST_ADDRESS    VARCHAR(30) NULL,
	RPT_ENT_CITY          VARCHAR(25) NULL,
	RPT_ENT_PROV          VARCHAR(2) NULL,
	RPT_ENT_POCODE        VARCHAR(8) NULL,
	RPT_ENT_TYPE          CHAR(1) NULL,
	 PRIMARY KEY (SAR_ID)
)
;



CREATE UNIQUE INDEX XPKREPORTING_ENTITY ON STR_REPORTING_ENTITY
(
	SAR_ID
)
;



CREATE TABLE AMLCTR.STR_THIRD_PARTY
(
	SAR_ID                NUMERIC(15,0) NOT NULL,
	TP_PART_SEQ_NUM       SMALLINT NOT NULL,
	TRAN_SEQ_NUM          SMALLINT NOT NULL,
	TP_PART_ID            CHAR(2) NOT NULL,
	TP_SURNAME            VARCHAR(20) NULL,
	TP_GIVEN_NAME         VARCHAR(15) NULL,
	TP_INITIAL            CHAR(1) NULL,
	TP_OTH_SURNAME        VARCHAR(20) NULL,
	TP_OTH_GIVEN_NAME     VARCHAR(15) NULL,
	TP_OTH_INITIAL        CHAR(1) NULL,
	TP_CLIENT_NUM         VARCHAR(12) NULL,
	TP_ST_ADDRESS         VARCHAR(30) NULL,
	TP_CITY               VARCHAR(25) NULL,
	TP_PROV               VARCHAR(20) NULL,
	TP_COUNTRY            CHAR(2) NULL,
	TP_POCODE             CHAR(9) NULL,
	TP_COUNTRY_RES        CHAR(2) NULL,
	TP_CITIZENSHIP        CHAR(2) NULL,
	TP_HOME_PH            VARCHAR(20) NULL,
	TP_HOME_PH_EXT        NUMERIC(10,0) NULL,
	TP_IDENT              CHAR(1) NULL,
	TP_IDENT_OTHER        VARCHAR(20) NULL,
	TP_IDENT_NUM          VARCHAR(20) NULL,
	TP_IDENT_ISSUE_PROV   VARCHAR(20) NULL,
	TP_IDENT_ISSUE_COUNTRY  CHAR(2) NULL,
	TP_DOB                CHAR(8) NULL,
	TP_OCC                VARCHAR(20) NULL,
	TP_BUSS_PH            CHAR(20) NULL,
	TP_BUSS_PH_EXT        NUMERIC(10,0) NULL,
	TP_EMPLYR             VARCHAR(35) NULL,
	TP_EMPLYR_ADDRESS     VARCHAR(30) NULL,
	TP_EMPLYR_CITY        VARCHAR(25) NULL,
	TP_EMPLYR_PROV        VARCHAR(20) NULL,
	TP_EMPLYR_COUNTRY     CHAR(2) NULL,
	TP_EMPLYR_POCODE      CHAR(9) NULL,
	TP_EMPLYR_BUSS_PH     VARCHAR(20) NULL,
	TP_EMPLYR_BUSS_PH_EXT  NUMERIC(10,0) NULL,
	 PRIMARY KEY (SAR_ID,TP_PART_SEQ_NUM,TRAN_SEQ_NUM)
)
;



CREATE UNIQUE INDEX XPKTHIRD_PARTY ON STR_THIRD_PARTY
(
	SAR_ID,
	TP_PART_SEQ_NUM,
	TRAN_SEQ_NUM
)
;



CREATE INDEX XIF1THIRD_PARTY ON STR_THIRD_PARTY
(
	TRAN_SEQ_NUM,
	SAR_ID
)
;



CREATE TABLE AMLCTR.STR_TRANSACTIONS
(
	SAR_ID                NUMERIC(15,0) NOT NULL,
	TRAN_SEQ_NUM          SMALLINT NOT NULL,
	TRAN_PART_ID          CHAR(2) NOT NULL,
	TRAN_DATE             CHAR(8) NULL,
	TRAN_TIME             CHAR(4) NULL,
	TRAN_BUS_HRS          CHAR(1) NULL,
	TRAN_POST_DATE        CHAR(8) NULL,
	TRAN_FUNDS_TYPE       CHAR(1) NULL,
	TRAN_FUNDS_OTH        VARCHAR(20) NULL,
	TRAN_AMOUNT           NUMERIC(13,2) NULL,
	TRAN_CURRENCY         CHAR(3) NULL,
	TRAN_OTH_PERSON_NAME  VARCHAR(35) NULL,
	TRAN_OTH_ACCT_NUM     VARCHAR(50) NULL,
	TRAN_METHOD           CHAR(1) NULL,
	TRAN_OTH_METHOD       VARCHAR(20) NULL,
	TELLER_ID             VARCHAR(15) NULL,
	 PRIMARY KEY (SAR_ID,TRAN_SEQ_NUM)
)
;



CREATE UNIQUE INDEX XPKTRANSACTION_ ON STR_TRANSACTIONS
(
	SAR_ID,
	TRAN_SEQ_NUM
)
;



CREATE INDEX XIF1TRANSACTION_ ON STR_TRANSACTIONS
(
	SAR_ID
)
;



ALTER TABLE AMLCTR.SAR_ALERTS
	ADD FOREIGN KEY R_3 (SAR_ID,SEGMENT_ID) REFERENCES AMLCTR.SAR_CNTL(SAR_ID,SEGMENT_ID)
;



ALTER TABLE AMLCTR.SAR_CNTL
	ADD FOREIGN KEY R_4 (SAR_TYPE) REFERENCES AMLCTR.SAR_TYPE_CODES(SAR_TYPE)
;


ALTER TABLE AMLCTR.SAR_CNTL
	ADD FOREIGN KEY R_5 (SAR_STATUS) REFERENCES AMLCTR.SAR_STATUS_CODES(SAR_STATUS)
;



ALTER TABLE AMLCTR.STR_ACTION
	ADD FOREIGN KEY R_17 (SAR_ID) REFERENCES AMLCTR.STR_REPORTING_ENTITY(SAR_ID)
;



ALTER TABLE AMLCTR.STR_BATCH_SUB_HEADER
	ADD FOREIGN KEY R_11 (BATCH_SEQ_ID,BATCH_DATE,BATCH_TIME) REFERENCES AMLCTR.STR_BATCH_HEADER(BATCH_SEQ_ID,BATCH_DATE,BATCH_TIME)
;



ALTER TABLE AMLCTR.STR_DISPOSITION
	ADD FOREIGN KEY R_1 (SAR_ID,TRAN_SEQ_NUM) REFERENCES AMLCTR.STR_TRANSACTIONS(SAR_ID,TRAN_SEQ_NUM)
;



ALTER TABLE AMLCTR.STR_NARATIVE
	ADD FOREIGN KEY R_19 (SAR_ID) REFERENCES AMLCTR.STR_REPORTING_ENTITY(SAR_ID)
;



ALTER TABLE AMLCTR.STR_THIRD_PARTY
	ADD FOREIGN KEY R_36 (SAR_ID,TRAN_SEQ_NUM) REFERENCES AMLCTR.STR_TRANSACTIONS(SAR_ID,TRAN_SEQ_NUM)
;



ALTER TABLE AMLCTR.STR_TRANSACTIONS
	ADD FOREIGN KEY R_16 (SAR_ID) REFERENCES AMLCTR.STR_REPORTING_ENTITY(SAR_ID)
;

SET FOREIGN_KEY_CHECKS = 1; 

create view BANK1KCTR.IDENTITY_DOCUMENT as select * from AMLCTR.IDENTITY_DOCUMENT;
create view BANK1KCTR.FINTRAC_COUNTRY_LOOKUP as select * from AMLCTR.FINTRAC_COUNTRY_LOOKUP;
create view BANK1KCTR.FINTRAC_TRANSACTION_TYPE_LOOKUP as select * from AMLCTR.FINTRAC_TRANSACTION_TYPE_LOOKUP;
create view BANK1KCTR.FIN_CONTACT_CONTROL as select * from AMLCTR.FIN_CONTACT_CONTROL;
create view BANK1KCTR.FIN_ENTITY_CONTROL as select * from AMLCTR.FIN_ENTITY_CONTROL;
create view BANK1KCTR.LSTR_ACTION as select * from AMLCTR.LSTR_ACTION;
create view BANK1KCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE as select * from AMLCTR.LSTR_LOGICAL_PHYSICAL_BRIDGE;
create view BANK1KCTR.LSTR_NARATIVE as select * from AMLCTR.LSTR_NARATIVE;
create view BANK1KCTR.LSTR_SUSPICIOUS_TRANSACTIONS as select * from AMLCTR.LSTR_SUSPICIOUS_TRANSACTIONS;
create view BANK1KCTR.STR_ACCOUNT_HOLDER_CORP as select * from AMLCTR.STR_ACCOUNT_HOLDER_CORP;
create view BANK1KCTR.STR_ACCOUNT_HOLDER_PERSONAL as select * from AMLCTR.STR_ACCOUNT_HOLDER_PERSONAL;
create view BANK1KCTR.STR_ACCOUNT_INFO as select * from AMLCTR.STR_ACCOUNT_INFO;
create view BANK1KCTR.STR_ACTION as select * from AMLCTR.STR_ACTION;
create view BANK1KCTR.STR_BATCH_HEADER as select * from AMLCTR.STR_BATCH_HEADER;
create view BANK1KCTR.STR_BATCH_RUN as select * from AMLCTR.STR_BATCH_RUN;
create view BANK1KCTR.STR_BATCH_SUB_HEADER as select * from AMLCTR.STR_BATCH_SUB_HEADER;
create view BANK1KCTR.STR_DISPOSITION as select * from AMLCTR.STR_DISPOSITION;
create view BANK1KCTR.STR_NARATIVE as select * from AMLCTR.STR_NARATIVE;
create view BANK1KCTR.STR_REPORTING_ENTITY as select * from AMLCTR.STR_REPORTING_ENTITY;
create view BANK1KCTR.STR_THIRD_PARTY as select * from AMLCTR.STR_THIRD_PARTY;
create view BANK1KCTR.STR_TRANSACTIONS as select * from AMLCTR.STR_TRANSACTIONS;
create view BANK1KCTR.SIC_LOOKUP as select * from AMLCTR.SIC_LOOKUP;

